# dockimg2md

Python command line program that takes in a word document and transfers the images to a markdown file.

## Usage:
```
docximg2md inputdocument markdownfile
```

where the inputdocumnet is the word document with the images, and the markdownfile is the name of the markdownfile you want to create containing the images.

## Example:
```
docximg2md document.docx mdfile.md
```